==> datalogic-android-sdk-1.42-sources.jar: com/datalogic/device/battery/ManufacturerInfo.java <==
package com.datalogic.device.battery;

/**
 * The <code>ManufacturerInfo</code> represents battery manufacturer information.
 */
public class ManufacturerInfo
{
    /**
     * Returns the battery model name in String form.
     *
     * @return <code>String</code>
     *         The battery model name.
     */
    public String getModelName()
    {
        return null;
    }

    /**
     * Returns the battery technology in String form.
     *
     * @return <code>String</code>
     *         The battery technology.
     */
    public String getTechnology()
    {
        return null;
    }

    /**
     * Returns the battery full design capacity (in MAh).
     *
     * @return <code>int</code>
     *         The full design capacity of the battery.
     */
    public int getFullCapacityDesign()
    {
        return 0;
    }

    /**
     * Returns the battery serial number.
     *
     * @return <code>String</code>
     *         The battery serial number.
     */
    public String getSerialNumber()
    {
        return null;
    }

    /**
     * Returns the week of production of the battery.
     *
     * @return <code>int</code>
     *         the week of production of the battery.
     */
    public int getProductionWeek()
    {
        return 0;
    }

    /**
     * Returns the month of production of the battery.
     *
     * @return <code>int</code>
     *         the week of production of the battery.
     */
    public int getProductionMonth()
    {
        return 0;
    }

    /**
     * Returns the year of production of the battery.
     *
     * @return <code>int</code>
     *         the year of production of the battery.
     */
    public int getProductionYear()
    {
        return 0;
    }

    /**
     * Returns the manufacturer name of the battery.
     *
     * @return <code>String</code>
     *         the manufacturer name of the battery.
     */
    public String getManufacturer()
    {
        return null;
    }

    /**
     * Returns the battery product number.
     *
     * @return <code>String</code>
     *         The battery product number.
     */
    public String getProductNumber()
    {
        return null;
    }

    /**
     * Returns the battery firmware version.
     *
     * @return <code>String</code>
     *         The battery firmware version.
     */
    public String getFirmwareVersion()
    {
        return null;
    }
}

==> datalogic-android-sdk-v1.43-sources.jar: com/datalogic/device/battery/ManufacturerInfo.java <==
package com.datalogic.device.battery;

/**
 * The <code>ManufacturerInfo</code> represents battery manufacturer information.
 */
public class ManufacturerInfo
{
    /**
     * Returns the battery model name in String form.
     *
     * @return <code>String</code>
     *         The battery model name.
     */
    public String getModelName()
    {
        return null;
    }

    /**
     * Returns the battery technology in String form.
     *
     * @return <code>String</code>
     *         The battery technology.
     */
    public String getTechnology()
    {
        return null;
    }

    /**
     * Returns the battery full design capacity (in MAh).
     *
     * @return <code>int</code>
     *         The full design capacity of the battery.
     */
    public int getFullCapacityDesign()
    {
        return 0;
    }

    /**
     * Returns the battery serial number.
     *
     * @return <code>String</code>
     *         The battery serial number.
     */
    public String getSerialNumber()
    {
        return null;
    }

    /**
     * Returns the week of production of the battery.
     *
     * @return <code>int</code>
     *         the week of production of the battery.
     */
    public int getProductionWeek()
    {
        return 0;
    }

    /**
     * Returns the month of production of the battery.
     *
     * @return <code>int</code>
     *         the week of production of the battery.
     */
    public int getProductionMonth()
    {
        return 0;
    }

    /**
     * Returns the year of production of the battery.
     *
     * @return <code>int</code>
     *         the year of production of the battery.
     */
    public int getProductionYear()
    {
        return 0;
    }

    /**
     * Returns the manufacturer name of the battery.
     *
     * @return <code>String</code>
     *         the manufacturer name of the battery.
     */
    public String getManufacturer()
    {
        return null;
    }

    /**
     * Returns the battery product number.
     *
     * @return <code>String</code>
     *         The battery product number.
     */
    public String getProductNumber()
    {
        return null;
    }

    /**
     * Returns the battery firmware version.
     *
     * @return <code>String</code>
     *         The battery firmware version.
     */
    public String getFirmwareVersion()
    {
        return null;
    }

    /**
     * Returns the battery rated capacity.
     *
     * @return <code>int</code>
     *         The battery rated capacity.
     */
    public int getRatedCapacity()
    {
        return 0;
    }

    /**
     * Returns the battery typical capacity.
     *
     * @return <code>int</code>
     *         The battery typical capacity.
     */
    public int getTypicalCapacity()
    {
        return 0;
    }
}
